<?php
/*
Plugin Name: WP tags to Technorati
Plugin URI: http://www.geekyramblings.org/plugins/wp-tags-to-technorati/
Description: Simple plugin to convert Wordpress 2.3's tags to Technorati ('http://technorati.com') links.
Version: 0.9
Author: David Gibbs
Author URI: http://www.geekyramblings.org
*/

/*

    Copyright 2007,2008 by David Gibbs <david@midrange.com>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*

Date		Rev	Modification
11/11/07	0.1	Initital version	
11/13/07	0.2	Added comment markups
11/14/07	0.3	Added class's to generated links and fixed problem
			with single tag.
11/16/07	0.4	Properly encode the generated tag url.
11/22/07	0.5	Added setting so user can change the prefix label
11/26/07	0.6	Added the ability to not include the tags in the 
			footer, so they could be manually put in a theme.
12/12/07	0.7	Added a control to allow technorati tags to open in
			a new window.  Also added version identifier to
 			comment.
02/27/08	0.8	Reformatted setup panel.
			tags2tech_get_tags_links() no longer needs to be
			echo'ed.  When invoked directly, it will output
			the links directly.  It will still work with the
			echo method though.
03/07/08	0.9	Fixed the positioning of the tags.
			tags2tech_get_tags_links() output must once again
			be echoed.
			Fixed a problem where this plug-in broke the 
			visual editor.
			
*/

$tags2tech_version = 0.9;

$tag_url = "http://technorati.com/tag";

$tag_start = "\n<!-- start wp-tags-to-technorati $tags2tech_version -->\n";
$tag_end = "\n<!-- end wp-tags-to-technorati -->\n";

set_magic_quotes_runtime(0);

function tags2tech_content ($text) {

	$include_footer = get_option('tags2tech_footer');

	if ($include_footer) {
		return $text.tags2tech_get_tags_links();
	} else {
		return $text;
	}

}

function tags2tech_get_tags_links() {

	global $tag_start,$tag_end;

	$new_window = get_option('tags2tech_new_window');

	$tags = get_the_tags();

	$tag_text = get_option('tags2tech_label')." ";
	
	$count=0;

	$tag_count=count($tags);

	if (is_array($tags)) {
		foreach($tags as $tag) {
			$count++;
			$link = tags2tech_get_link($tag->name,$new_window);
			$tag_text = $tag_text.($count>1?', ':'').$link;
		}
		$tag_links = "\n<p class='technorati-tags'>".$tag_text."</p>\n";
	} elseif ($tags->name != "") {
		$tag_links = "\n<p class='technorati-tags'>".$tag_text.tags2tech_get_link($tags->name,$new_window)."</p>\n";
	} else {
		$tag_links = "";
	}

	return $tag_start.$tag_links.$tag_end;
}

function tags2tech_get_link($tag,$new_window = false) {
	global $tag_url;

	$encoded_tag = urlencode($tag);

	$target = $new_window?'_blank':'_self';

	$link = "<a class='technorati-link' href='$tag_url/$encoded_tag' rel='tag' target='$target'>$tag</a>";
	
	return $link;
}

function tags2tech_options_menu() {

	?>
	<div class="wrap">
	<h2>Tags to Technorati Settings</h2>
	<form method="post" action="options.php">
	 <!-- <?php echo $_SERVER['PHP_SELF']; ?>?page=<?php echo attribute_escape($_GET['page']); ?>"> -->
	<?php wp_nonce_field('update-options'); ?>

<table class="form-table">
 <tr>
 	<th scope="row" valign="top">Technorati Tags label:</th>
 	<td>
	<input id="tags2tech_label" type="text" name="tags2tech_label" value="<?php echo get_option('tags2tech_label'); ?>" />
  	 	<label for="inputid">Text that will display in front of the tags</label>
 	</td>
 </tr>
 <tr>
 	<th scope="row" valign="top">Open Technorati links in a new window?</th>
 	<td>
	<input id=tags2tech_new_window" type="checkbox" name="tags2tech_new_window" <?php echo get_option('tags2tech_new_window')?'checked=checked':''; ?> /> 
  	 	<label for="tags2tech_new_window">Check this box to open links to Technorati in a new window.</label>
 	</td>
 </tr>
 <tr>
 	<th scope="row" valign="top">Include tags in post footer?</th>
 	<td>
	<input id="tags2tech_footer" type="checkbox" name="tags2tech_footer" <?php echo get_option('tags2tech_footer')?'checked=checked':''; ?> /> 
  	 	<label for="tags2tech_footer">If you want to include the links in any other location on the page than the footer, disable this checkbox and add a call to <code>tags2tech_get_tags_links()</code> somewhere in the main wordpress 'loop'.</label>
 	</td>
 </tr>
</table>


        <p class="submit">
        <input type="submit" name="Submit" value="Save Changes" />
        </p>
	<input type="hidden" name="action" value="update" />
	<input type="hidden" name="page_options" value="tags2tech_label,tags2tech_footer,tags2tech_new_window"/>
	</form>
	</div>
	<?php 

}

function tags2tech_menu(){
    add_options_page('Tags to Technorati', 'Tags to Technorati', 8, __FILE__, 'tags2tech_options_menu');
}

function tags2tech_checkupgrade() {
	global $tags2tech_version;

	$last_version = get_option('tags2tech_version');
	$current_version = $tags2tech_version;
	if ($current_version > $last_version) {
		echo "<!-- upgrading to $tags2tech_version -->\n";
		$label = get_option('tags2tech_label');
		echo "<!-- oldlabel = $label -->\n";
		if (substr($label,-1) <> ":") {
			$newlabel = $label.":";
			update_option('tags2tech_label',$newlabel);
		}
		update_option('tags2tech_version',$tags2tech_version);
	}

}

function tags2tech_activate()
{
        // Let's add some options
	// add_option('tags2tech_label', 'Technorati Tags');
}

function tags2tech_deactivate()
{
        // Clean up the options
	delete_option('tags2tech_label');
	delete_option('tags2tech_footer');
	delete_option('tags2tech_new_window');
}

add_option('tags2tech_version', $tags2tech_version);
add_option('tags2tech_label', 'Technorati Tags:');
add_option('tags2tech_footer', true);
add_option('tags2tech_new_window', false);
add_filter('the_content', 'tags2tech_content');
add_action('admin_menu', 'tags2tech_menu');

// register_activation_hook( __FILE__, 'tags2tech_activate' );

add_action('activate_wp-tags-to-technorati/wp-tags-to-technorati.php',
	'tags2tech_activate');
add_action('deactivate_wp-tags-to-technorati/wp-tags-to-technorati.php',
	'tags2tech_deactivate');

// add_action('wp_head','tags2tech_checkupgrade');
add_action('plugins_loaded','tags2tech_checkupgrade');

?>
